#  OpenDeco - An implementation of the Varying Permeability Model used for
#             calculating diving decompression tables
#  Copyright (C) 2007 Konrad Wojas <konrad@opendeco.org>
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 2.1 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

class Unit(object):

    _baseclass = None
    unitname = None

    # FIXME: cmp

    def __init__(self, value):
        self.value = value

    def __str__(self):
        return "%f %s" % (self.value, self.unitname)

    def __repr__(self):
        return "%f %s" % (self.value, self.unitname)

    def __mul__(self, v):
        return self.__class__(self.value * v)

    def __rmul__(self, v):
        return self.__class__(self.value * v)

    def __div__(self, v):
        if isinstance(v, self._baseclass):
            return self.value / getattr(v, self.unitname)
        else:
            return self.__class__(self.value / v)

    def __add__(self, v):
        assert isinstance(v, self._baseclass)
        return self.__class__(self.value + getattr(v, self.unitname))

    def __sub__(self, v):
        assert isinstance(v, self._baseclass)
        return self.__class__(self.value - getattr(v, self.unitname))


class DepthUnit(Unit):

    # 1.00 atm  =  760.0 mm Hg  =  101.325 kPa  =  101,325 Pa
    # implement these for your unit
    # FIXME salt/fresh

    @property
    def bar(self):
        raise NotImplementedError()
   
    # the rest should be ok as is

    value = None
    
    @property
    def msw(self):
        return self.bar * 10.0
        #return self.bar * 10.1325

    @property
    def fsw(self):
        return self.bar * 100.0 / 3

    @property
    def atm(self):
        return self.bar / 1.01325

    @property
    def mmHg(self):
        return self.atm * 760.0

    @property
    def pascal(self):
        return self.bar * 1e5


class MeterSeaWater(DepthUnit):
    # FIXME Units_Factor = 10.1325
    unitname = 'msw'
    _baseclass = DepthUnit
    @property
    def bar(self):
        return self.value / 10.0
        #return self.value / 10.1325

class FeetSeaWater(DepthUnit):
    # FIXME 33.0
    unitname = 'fsw'
    _baseclass = DepthUnit
    @property
    def bar(self):
        return self.value / 100.0 * 3

class Bar(DepthUnit):
    unitname = 'bar'
    _baseclass = DepthUnit
    @property
    def bar(self):
        return self.value

class Atm(DepthUnit):
    unitname = 'atm'
    _baseclass = DepthUnit
    @property
    def bar(self):
        return self.value * 1.01325

class MmHg(DepthUnit):
    unitname = 'mmHg'
    _baseclass = DepthUnit
    @property
    def bar(self):
        return self.value * 1.01325 / 760.0


msw = MeterSeaWater(1.0)
fsw = FeetSeaWater(1.0)
bar = Bar(1.0)
atm = Atm(1.0)
mmHg = MmHg(1.0)

