"""
Helper functions for opendeco plots to avoid duplication in plot scripts
"""

import os
import sys
import pylab
import numpy
import time

from opendeco.diveseries import *
from opendeco import vpm, tracker, mix
from opendeco.units import msw

t0 = [None]
cum_t = [0.0]

def timer(s=''):
    t1 = time.time()
    if t0[0]:
        dt = t1 - t0[0]
        cum_t[0] += dt
        print "<%s> This step took %.3fs, total %.3fs" % (s, dt, cum_t[0])
    t0[0] = t1

def outbase(pyfile):
    """
    Return base path for output
    pyfile: __file__
    """
    return "output/" + os.path.splitext(os.path.basename(pyfile))[0]

def savefig(base, *args,**kwargs):
    for ext in ['.png', '.svg', '.pdf', '.eps']:
        pylab.savefig(base+ext, *args, **kwargs)

def show(clickhandler=True):
    batch = os.getenv('batch', False)
    if not batch:
        if clickhandler:
            # exit on click
            pylab.connect('button_press_event', lambda event: sys.exit(0)) 
        pylab.show()

def ext():
    plot = os.getenv('plot', 'png')
    return '.' + plot
        
def simpleProfile(gas, depth, time, rate=30):
    p = DiveProfile()
    ch = SegmentChange(gas, 0*msw, depth*msw, rate*msw)
    p.addSegment(ch)
    p.addSegment(SegmentLevel(gas, depth*msw, time - ch.time))
    return p

def smoothplot(x, y, dx):
    newx = [x[0]]
    newy = [y[0]]
    for i in range(1, len(x)):
        if (x[i] - x[i-1]) < dx and y[i]==y[i-1]:
            # drop it
            pass
        else:
            newx.append(x[i])
            newy.append(y[i])
    return numpy.array(newx), numpy.array(newy)
        
def fullProfile(meters=True, iteration=None):
    """
    Returns the profile with last deco iteration appended
    """
    if iteration is None:
        nr_it = tracker.current.plotdata('vpm.iterations').y[0]
    else:
        nr_it = iteration
    d = tracker.current.plotdata('profile.depth')
    dd = tracker.current.plotdata('profile.deco.iter%i.depth' % nr_it)
    x = numpy.array(d.x.tolist() + dd.x.tolist())
    y = numpy.array(d.y.tolist() + dd.y.tolist())
    if meters:
        y = y * 10
    return x, y

def printSchedule(vpm_instance):
    for sd, sl, sr, sm in vpm_instance.lastSchedule:
        print "%3i %2i (%3i) %s" % (sd.msw, sl, sr, sm.shortname())

def runErikBaker(depth, divetime, bottom=mix.Air, deco=[], binary='vpmb-orig'):
    """
    Run Erik Baker's fortran program to compare
    Make sure to chdir() first
    """
    f = open('VPMDECO.IN', 'w')
    l = []
    l.append('runErikBaker() generated')
    # mixes
    l.append("%s" % (len(deco)+1))
    for g in [bottom] + [ x[1] for x in deco ]:
        ("%.2f,%.2f,%.2f" % (g.o2, g.he, g.n2))
        l.append("%.2f,%.2f,%.2f" % (g.o2, g.he, g.n2))
    # descent
    l.append('1')
    l.append('0,%i,30,1' % depth)
    # bottom
    l.append('2')
    l.append('%i,%i,1' % (depth, divetime))
    # deco
    l.append('99')
    # switches and stops
    l.append("%s" % (len(deco)+1))
    l.append('%i,1,-10,3' % (depth))
    i = 2
    for d, g in deco:
        l.append('%i,%i,-10,3' % (d.msw, i))
        i += 1
    l.append('0')
    f.write('\r\n'.join(l))   
    f.write('\r\n')   
    f.close()
    os.system('./%s > /dev/null' % binary)

    o = open('VPMDECO.OUT', 'r')
    lines = [ x for x in o ]
    o.close()
    runtime = float(lines[-2].strip()[12:17])
    
    return runtime, lines
    


