#<example
# this is the Matplotlib Matlab(R) style programming interface
from pylab import *

# opendeco.vpm contain the VPM class, opendeco.mix all gas 
# mixture functions
from opendeco import vpm, mix

# import the 'meters of seawater' unit
from opendeco.units import msw

# this contains some convenience functions for creating 
# plots from opendeco
import common

depth = 60
divetime = 30

# simpleProfile is a convenience function in common.py
# to create simple dive profile with a descent rate of 
# 30 m/min
bottomgas = mix.Tx(18, 45)
profile = common.simpleProfile(bottomgas, depth, divetime)

# create a VPM instance with conservatism +2
v = vpm.VPM(conservatism=2)

# define the decompression gasses to be used
deco = [
    (6*msw, mix.Oxygen),
    (21*msw, mix.EAN(50))
]
v.decoMixes = deco

# do dive calculation
v.runProfile(profile)

# fullProfile is a convenience function in common.py to
# get the current dive profile in meters from the tracker
x, y = common.fullProfile()

# plot the dive profile
plotref = plot(x, -y, '-', linewidth=1)

# set a few plot parameters
legend([plotref], ['Tx18/45 + EAN50 + O2'], loc='best')
title('Dive at conservatism +2 with various decogasses')
xlabel('Runtime (min)')
ylabel('Depth (m)')

# export to Encapsulated PostScript format
# and to Portable Network Graphics format
savefig('output/example.eps')
savefig('output/example.png')

# popup a window with dive profile
show()
#>example
