#<example
# this is the Matplotlib Matlab(R) style programming interface
from pylab import *

# opendeco.vpm contain the VPM class, opendeco.mix all gas 
# mixture functions
from opendeco import vpm, mix
from opendeco.diveseries import *

# import the 'meters of seawater' unit
from opendeco.units import msw

# this contains some convenience functions for creating 
# plots from opendeco
import common

depth = 55
divetime = 30

# simpleProfile is a convenience function in common.py
# to create simple dive profile with a descent rate of 
# 30 m/min
#bottomgas = mix.Tx(18, 45)
bottomgas = mix.Air
profile = common.simpleProfile(bottomgas, depth, divetime)

usn_x = [30, 34.6, 41, 41.3, 58, 58.3, 75, 75.3]
usn_y = [-55, -9, -9, -6, -6, -3, -3, 0]

# create a VPM instance with conservatism +2
v = vpm.VPM(conservatism=0, useBoylesLawCompensation=False)

# define the decompression gasses to be used
deco = [
#    (6*msw, mix.Oxygen),
#    (21*msw, mix.EAN(50))
]
v.decoMixes = deco

# do dive calculation
v.runProfile(profile)

# fullProfile is a convenience function in common.py to
# get the current dive profile in meters from the tracker
x, y = common.fullProfile()

# plot the dive profile
plotref = plot(x, -y, '-', linewidth=1)
usnref = plot(usn_x, usn_y, '-', linewidth=1)

# set a few plot parameters
legend([plotref, usnref], ['VPM (not B) nominal', 'US Navy tables (Haldane)'], loc='best')
title('VPM vs Haldane')
xlabel('Runtime (min)')
ylabel('Depth (m)')

# export to Encapsulated PostScript format
# and to Portable Network Graphics format
savefig('output/haldane-vpm.png')

# popup a window with dive profile
common.show()
#>example
